@@ -1,17 +1,19 @@
 from fastapi import Depends, FastAPI
-from typing import List, Any
 from fastapi.middleware.cors import CORSMiddleware
 
-from backend.db import create_db_and_tables
-from backend.core.auth import auth_backend, fastapi_users
+% if auth:
+from backend.models.user import UserDB
+from backend.core.auth import auth_backend, current_active_user, fastapi_users
 from backend.api.endpoints.user_endpoints import router as user_routes
+% endif
+
 
 app = FastAPI()
 
 origins = [
     "http://localhost:8080",
-    "http://localhost:8081",
-] 
+    "http://localhost:3000",
+]
 app.add_middleware(
     CORSMiddleware,
     allow_origins=origins,
@@ -21,17 +23,7 @@ app.add_middleware(
 )
 
 
-@app.on_event("startup")
-async def on_startup():
-% if alembic:
-    await create_db_and_tables()
-% else:
-    pass
-% endif
-
-
-
-
+% if auth:
 app.include_router(
     fastapi_users.get_auth_router(auth_backend), prefix="/auth/jwt", tags=["auth"]
 )
@@ -47,4 +39,9 @@ app.include_router(
     tags=["auth"],
 )
 app.include_router(fastapi_users.get_users_router(), prefix="/users", tags=["users"])
-app.include_router(user_routes)
+
+
+@app.get("/authenticated-route")
+async def authenticated_route(user: UserDB = Depends(current_active_user)):
+    return {"message": f"Hello {user.email}!"}
+% endif
